@@ -31,10 +31,8 @@ mas = mas2rad*180/np.pi
 
 # loads data needed to find astrometric error as functon of magnitude
 local_dir = os.path.dirname(__file__) #<-- absolute dir the script is in
-print(local_dir)
-rel_path = '/../data/scatteral_edr3.csv'
+rel_path = '/data/scatteral_edr3.csv'
 abs_file_path = local_dir+rel_path #os.path.join(local_dir, rel_path)
-print(abs_file_path)
 sigma_al_data = np.genfromtxt(abs_file_path,skip_header=1,delimiter=',',unpack=True)
 mags=sigma_al_data[0]
 sigma_als=sigma_al_data[1]
